@@ -2,7 +2,7 @@
 # Kernel/Modules/AgentZoom.pm - to get a closer view
 # Copyright (C) 2001-2004 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: AgentZoom.pm,v 1.49.2.1 2004/04/11 16:55:01 martin Exp $
+# $Id: AgentZoom.pm,v 1.70.2.1 2004/10/08 11:24:18 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -15,18 +15,18 @@ use strict;
 use Kernel::System::CustomerUser;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.49.2.1 $';
+$VERSION = '$Revision: 1.70.2.1 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 # --
 sub new {
     my $Type = shift;
     my %Param = @_;
-   
-    # allocate new hash for object 
-    my $Self = {}; 
+
+    # allocate new hash for object
+    my $Self = {};
     bless ($Self, $Type);
-    
+
     foreach (keys %Param) {
         $Self->{$_} = $Param{$_};
     }
@@ -35,7 +35,9 @@ sub new {
       QueueObject ConfigObject UserObject SessionObject)) {
         die "Got no $_!" if (!$Self->{$_});
     }
-    # get params 
+    # set debug
+    $Self->{Debug} = 0;
+    # get params
     $Self->{ArticleID} = $Self->{ParamObject}->GetParam(Param => 'ArticleID');
     $Self->{ZoomExpand} = $Self->{ParamObject}->GetParam(Param => 'ZoomExpand');
     $Self->{ZoomExpandSort} = $Self->{ParamObject}->GetParam(Param => 'ZoomExpandSort');
@@ -96,12 +98,12 @@ sub Run {
       }  
     }
     # get content
-    my %Ticket = $Self->{TicketObject}->GetTicket(TicketID => $Self->{TicketID});
-    my %TicketLink = $Self->{TicketObject}->GetTicketLink(
+    my %Ticket = $Self->{TicketObject}->TicketGet(TicketID => $Self->{TicketID});
+    my %TicketLink = $Self->{TicketObject}->TicketLinkGet(
         TicketID => $Self->{TicketID},
         UserID => $Self->{UserID},
     );
-    my @ArticleBox = $Self->{TicketObject}->GetArticleContentIndex(TicketID => $Self->{TicketID});
+    my @ArticleBox = $Self->{TicketObject}->ArticleContentIndex(TicketID => $Self->{TicketID});
     # --
     # return if HTML email
     # --
@@ -128,14 +130,21 @@ sub Run {
             return $Output;
         }
         # if it is a html email, return here
-        return $Self->MaskAgentZoomHTML(%Ticket, %Article);
+        return $Self->{LayoutObject}->Attachment(
+            Filename => $Self->{ConfigObject}->Get('TicketHook')."-$Article{TicketNumber}-$Article{TicketID}-$Article{ArticleID}",
+            Type => 'inline',
+            ContentType => "$Article{MimeType}; charset=$Article{ContentCharset}",
+            Content => $Article{Body},
+        );
     }
     # --
     # else show normal ticket zoom view
     # --
     # fetch all move queues
-    my %MoveQueues = $Self->{QueueObject}->GetAllQueues(
+    my %MoveQueues = $Self->{TicketObject}->MoveList(
+        TicketID => $Self->{TicketID},
         UserID => $Self->{UserID},
+        Action => $Self->{Action},
         Type => 'move_into',
     );
     # fetch all std. responses
@@ -173,10 +182,10 @@ sub Run {
         StdResponses => \%StdResponses,
         ArticleBox => \@ArticleBox,
         CustomerData => \%CustomerData,
-        TicketTimeUnits => $Self->{TicketObject}->GetAccountedTime(%Ticket),
-        %Ticket,
-        %TicketLink,
+        TicketTimeUnits => $Self->{TicketObject}->TicketAccountedTimeGet(%Ticket),
         %UserInfo,
+        %TicketLink,
+        %Ticket,
     );
     # add footer 
     $Output .= $Self->{LayoutObject}->Footer();
@@ -187,7 +196,19 @@ sub Run {
 sub MaskAgentZoom {
     my $Self = shift;
     my %Param = @_;
+    # get ack actions 
+    $Self->{TicketObject}->TicketAcl(
+        Data => '-',
+        Action => $Self->{Action},
+        TicketID => $Self->{TicketID},
+        ReturnType => 'Action',
+        ReturnSubType => '-',
+        UserID => $Self->{UserID},
+    );
+    my %AclAction = $Self->{TicketObject}->TicketAclActionData();
+    # age design
     $Param{Age} = $Self->{LayoutObject}->CustomerAge(Age => $Param{Age}, Space => ' ');
+    $Param{SLAAge} = $Self->{LayoutObject}->CustomerAge(Age => $Param{SLAAge}, Space => ' ');
     if ($Param{UntilTime}) {
         if ($Param{UntilTime} < -1) {
             $Param{PendingUntil} = "<font color='$Self->{HighlightColor2}'>";
@@ -249,12 +270,18 @@ sub MaskAgentZoom {
     foreach my $ArticleTmp (@ArticleBox) {
       my %Article = %$ArticleTmp;
       $TicketOverTime = $Article{TicketOverTime}; 
-      if ($Article{ArticleType} !~ /^email-notification/i) {
+      if ($Article{ArticleType} !~ /^email-notification/i) { 
+        my $TmpSubject = $Article{Subject};
+        my $TicketHook = $Self->{ConfigObject}->Get('TicketHook') || '';
+        $TmpSubject =~ s/^..: //;
+        $TmpSubject =~ s/\[$TicketHook: $Article{TicketNumber}\] //g;
+        my $TitleShort = $Self->{LayoutObject}->Ascii2Html(Text => $Article{From}, Max => 16).': '.$Self->{LayoutObject}->Ascii2Html(Text => $TmpSubject, Max => 20).' - $TimeLong{"'.$Article{Created}.'"}';
+        my $Title = $Self->{LayoutObject}->Ascii2Html(Text => $Article{From}, Max => 50).': '.$Self->{LayoutObject}->Ascii2Html(Text => $TmpSubject, Max => 200).' - $TimeLong{"'.$Article{Created}.'"}';
         $ThreadStrg .= '<tr class="'.$Article{SenderType}.'-'.$Article{ArticleType}.'"><td class="small">';
-        $ThreadStrg .= '<div title="'.$Self->{LayoutObject}->Ascii2Html(Text => $Article{Subject}, Max => 200).' - $TimeLong{"'.$Article{Created}.'"}">';
+        $ThreadStrg .= '<div title="'.$Title.'">';
         if ($LastSenderType ne $Article{SenderType}) {
-            $Counter .= "&nbsp;&nbsp;";
-            $Space = "$Counter |--&gt;";
+            $Counter .= "&nbsp;";
+            $Space = "$Counter&nbsp;|--&gt;";
         }
         $LastSenderType = $Article{SenderType};
         $ThreadStrg .= "$Space";
@@ -267,7 +294,7 @@ sub MaskAgentZoom {
         # --
         # the full part thread string
         # --
-        $ThreadStrg .= "<a href=\"$BaseLink"."Action=AgentZoom&ArticleID=$Article{ArticleID}#$Article{ArticleID}\"" .
+        $ThreadStrg .= "<a href=\"$BaseLink"."Action=AgentZoom&ArticleID=$Article{ArticleID}#$Article{ArticleID}\" ".
            'onmouseover="window.status=\''."\$Text{\"$Article{SenderType}\"} (".
            "\$Text{\"$Article{ArticleType}\"})".'\'; return true;" onmouseout="window.status=\'\';">'.
            "\$Text{\"$Article{SenderType}\"} (\$Text{\"$Article{ArticleType}\"})</a> ";
@@ -276,7 +303,7 @@ sub MaskAgentZoom {
              'onmouseover="window.status=\'$Text{"plain"}'.
              '\'; return true;" onmouseout="window.status=\'\';">$Text{"plain"}</a>)';
         }
-        $ThreadStrg .= '&nbsp;-&nbsp;'.$Self->{LayoutObject}->Ascii2Html(Text => $Article{Subject}, Max => 20).'&nbsp;-&nbsp;$TimeLong{"'.$Article{Created}.'"}';
+        $ThreadStrg .= '&nbsp;'.$TitleShort;
         # --
         # if this is the shown article -=> add </b>
         # --
@@ -346,11 +373,59 @@ sub MaskAgentZoom {
     # --
     $Param{TicketStatus} .= $Self->{LayoutObject}->Output(
         TemplateFile => 'AgentZoomStatus',
-        Data => {%Param},
+        Data => {%Param, %AclAction},
     );
     my $BodyOutput = '';
     foreach my $ArticleTmp (@NewArticleBox) {
         my %Article = %$ArticleTmp;
+        # run article modules
+        if (ref($Self->{ConfigObject}->Get('Frontend::ArticleModule')) eq 'HASH') {
+            my %Jobs = %{$Self->{ConfigObject}->Get('Frontend::ArticleModule')};
+            foreach my $Job (sort keys %Jobs) {
+                # log try of load module
+                if ($Self->{Debug} > 1) {
+                    $Self->{LogObject}->Log(
+                        Priority => 'debug',
+                        Message => "Try to load module: $Jobs{$Job}->{Module}!",
+                    );
+                }
+                if (eval "require $Jobs{$Job}->{Module}") {
+                    my $Object = $Jobs{$Job}->{Module}->new(
+                        ConfigObject => $Self->{ConfigObject},
+                        LogObject => $Self->{LogObject},
+                        DBObject => $Self->{DBObject},
+                        LayoutObject => $Self->{LayoutObject},
+                        TicketObject => $Self->{TicketObject},
+                        ArticleID => $Article{ArticleID},
+                        UserID => $Self->{UserID},
+                        Debug => $Self->{Debug},
+                    );
+                    # log loaded module
+                    if ($Self->{Debug} > 1) {
+                        $Self->{LogObject}->Log(
+                            Priority => 'debug',
+                            Message => "Module: $Jobs{$Job}->{Module} loaded!",
+                        );
+                    }
+                    # run module
+                    my @Data = $Object->Check(Article=> \%Article, %Param, Config => $Jobs{$Job});
+                    foreach my $DataRef (@Data) {
+                        $Self->{LayoutObject}->Block(
+                             Name => 'ArticleOption',
+                             Data => $DataRef,
+                        );
+                    }
+                    # filter option
+                    $Object->Filter(Article=> \%Article, %Param, Config => $Jobs{$Job});
+                }
+                else {
+                    $Self->{LogObject}->Log(
+                        Priority => 'error',
+                        Message => "Can't load module $Jobs{$Job}->{Module}!",
+                    );
+                }
+            }
+        }
         # delete ArticleStrg and TicketStatus if it's not the first shown article
         if ($BodyOutput) {
             $Param{ArticleStrg} = '';
@@ -367,14 +442,50 @@ sub MaskAgentZoom {
         if ($Article{Atms}) {
             %AtmIndex = %{$Article{Atms}};
         }
-        $Article{"ATM"} = '';
-        foreach (keys %AtmIndex) {
-            $AtmIndex{$_} = $Self->{LayoutObject}->Ascii2Html(Text => $AtmIndex{$_});
-            $Article{"ATM"} .= '<a href="$Env{"Baselink"}Action=AgentAttachment&'.
-              "ArticleID=$Article{ArticleID}&FileID=$_\" target=\"attachment\" ".
-              "onmouseover=\"window.status='\$Text{\"Download\"}: $AtmIndex{$_}';".
+        $Article{"ATM"} = '<table border="0" cellspacing="0" cellpadding="1">';
+        foreach my $FileID (keys %AtmIndex) {
+            my %File = %{$AtmIndex{$FileID}};
+            # check viewer
+            my $Viewer = '';
+            if ($Self->{ConfigObject}->Get('MIME-Viewer')) {
+                foreach (keys %{$Self->{ConfigObject}->Get('MIME-Viewer')}) {
+                    if ($File{ContentType} =~ /^$_/i) {
+                        $Viewer = $Self->{ConfigObject}->Get('MIME-Viewer')->{$_};
+                    }
+                }
+            }
+            # build link
+            $File{Filename} = $Self->{LayoutObject}->Ascii2Html(Text => $File{Filename});
+            # download type
+            my $Type = $Self->{ConfigObject}->Get('Agent::DownloadType') || 'attachment';
+            # if attachment will be forced to download, don't open a new download window!
+            my $Target = '';
+            if ($Type =~ /inline/i) {
+                $Target = 'target="attachment" ';
+            }
+            my $Link = "\$Env{\"Baselink\"}Action=AgentAttachment&ArticleID=$Article{ArticleID}&FileID=$FileID";
+            $Article{"ATM"} .= "<tr><td>$File{Filename}</td>";
+            $Article{"ATM"} .= "<td><a href=\"$Link\" $Target".
+              "onmouseover=\"window.status='\$Text{\"Download\"}: $File{Filename}';".
               ' return true;" onmouseout="window.status=\'\';">'.
-              $AtmIndex{$_}.'</a><br> ';
+              "<img src=\"\$Env{\"Images\"}disk-s.png\" border=\"0\" alt=\"\$Text{\"Download\"}\"></a></td><td> ";
+             if ($Viewer) {
+                 $Article{"ATM"} .= "<a href=\"$Link&Viewer=1\" target=\"attachment\" ".
+              "onmouseover=\"window.status='\$Text{\"View\"}: $File{Filename}';".
+              ' return true;" onmouseout="window.status=\'\';">'.
+              "<img src=\"\$Env{\"Images\"}screen-s.png\" border=\"0\" alt=\"\$Text{\"Viewer\"}\"></a>";
+             }
+             $Article{"ATM"} .= "</td><td align='right'> $File{Filesize}</td></tr>";
+        }
+        $Article{"ATM"} .= '</table>';
+        if (%AtmIndex) {
+            $Self->{LayoutObject}->Block(
+                Name => 'ArticleAttachment',
+                Data => {
+                    Key => 'Attachment',
+                    Value => $Article{"ATM"},
+                },
+            );
         }
         # do some strips && quoting
         foreach (qw(From To Cc Subject Body)) {
@@ -383,6 +494,29 @@ sub MaskAgentZoom {
                 From => $Article{ContentCharset},
             );
         }
+        foreach (qw(From To Cc Subject)) {
+            if ($Article{$_}) {
+                $Self->{LayoutObject}->Block(
+                    Name => 'Row',
+                    Data => {
+                        Key => $_,
+                        Value => $Article{$_},
+                    },
+                );
+            }
+        }
+        foreach (qw(1 2 3 4 5)) {
+            if ($Article{"FreeText$_"}) {
+                $Self->{LayoutObject}->Block(
+                    Name => 'ArticleFreeText',
+                    Data => {
+                        Key => $Article{"FreeKey$_"},
+                        Value => $Article{"FreeText$_"},
+                    },
+                );
+            }
+        }
+
         # check if just a only html email
         if (my $MimeTypeText = $Self->{LayoutObject}->CheckMimeType(%Param, %Article)) {
             $Article{"BodyNote"} = $MimeTypeText;
@@ -414,16 +548,16 @@ sub MaskAgentZoom {
             if ($Self->{ConfigObject}->Get('AgentCanBeCustomer') && $Param{CustomerUserID} =~ /^$Self->{UserLogin}$/i) {
               $Article{TicketAnswer} = $Self->{LayoutObject}->Output(
                 TemplateFile => 'AgentZoomAgentIsCustomer',
-                Data => {%Param, %Article},
+                Data => {%Param, %Article, %AclAction},
               );
             }
             $Article{TicketArticle} = $Self->{LayoutObject}->Output(
                 TemplateFile => 'AgentZoomArticle',
-                Data => {%Param, %Article},
+                Data => {%Param, %Article, %AclAction},
             );
             $BodyOutput .= $Self->{LayoutObject}->Output(
                 TemplateFile => 'AgentZoomBody', 
-                Data => {%Param, %Article},
+                Data => {%Param, %Article, %AclAction},
             );
         }
         else {
@@ -431,49 +565,36 @@ sub MaskAgentZoom {
             if ($Self->{ConfigObject}->Get('AgentCanBeCustomer') && $Param{CustomerUserID} =~ /^$Self->{UserLogin}$/i) {
               $Article{TicketAnswer} = $Self->{LayoutObject}->Output(
                 TemplateFile => 'AgentZoomAgentIsCustomer',
-                Data => {%Param, %Article},
+                Data => {%Param, %Article, %AclAction},
               );
             }
             else {
               $Article{TicketAnswer} = $Self->{LayoutObject}->Output(
                   TemplateFile => 'AgentZoomAnswer',
-                  Data => {%Param, %Article},
+                  Data => {%Param, %Article, %AclAction},
               );
               $Article{TicketArticle} = $Self->{LayoutObject}->Output(
                   TemplateFile => 'AgentZoomArticle',
-                  Data => {%Param, %Article},
+                  Data => {%Param, %Article, %AclAction},
               );
             }
             $BodyOutput .= $Self->{LayoutObject}->Output(
                 TemplateFile => 'AgentZoomBody', 
-                Data => {%Param, %Article},
+                Data => {%Param, %Article, %AclAction},
             );
         }
     }
     my $Output = $Self->{LayoutObject}->Output(
         TemplateFile => 'AgentZoomHead', 
-        Data => \%Param, 
+        Data => {%Param, %AclAction}, 
     );
     $Output .= $BodyOutput;
     $Output .= $Self->{LayoutObject}->Output(
         TemplateFile => 'AgentZoomFooter', 
-        Data => \%Param,
+        Data => {%Param, %AclAction},
     );
     # return output
     return $Output;
 }
 # --
-sub MaskAgentZoomHTML {
-    my $Self = shift;
-    my %Param = @_;
-    # generate output
-    my $Output = "Content-Disposition: inline; filename=";
-    $Output .= $Self->{ConfigObject}->Get('TicketHook')."-$Param{TicketNumber}-";
-    $Output .= "$Param{TicketID}-$Param{ArticleID}\n";
-    $Output .= "Content-Type: $Param{MimeType}; charset=$Param{ContentCharset}\n";
-    $Output .= "\n";
-    $Output .= $Param{"Body"};
-    return $Output;
-}
-# --
 1;
